; Copyright (c) 2004-2010, Stubbe F. Hviid
;   All rights reserved
;+
; NAME:
;   FUNCTION osiris_quality_values
;
; PURPOSE:
;   Defines the various values available in an OSIRIS quality map
;
; CATEGORY:
;   Osiris CCD Calibration
;
; CALLING SEQUENCE:
;  Result = osiris_quality_values()
;
; INPUTS:
;   None
;
; KEYWORD PARAMETERS:
;   None
;
; RETURNS:
;   structure containing names entries for each type of valid quality map bits
;
; RESTRICTIONS:
;   None
;
; EXAMPLE:
;   qmv = osiris_quality_values()
;
; MODIFICATION HISTORY:
;   Written by:  Stubbe F. Hviid   8/4-2010
;-

FUNCTION osiris_quality_values

	return, {sqrt_filtered:   1, $	// quality value for pixels that have been sqrt filtered
			 conv_filtered:   2, $	// quality value for pixels that have been convolution filtered
			 non_linear_ccd:  4, $	// quality value for pixels with DN values in the non linear range
			 lossy_comp:      8, $	// quality value for pixels that have been lossy compressed
			 warm_pixel:	 16, $	// quality map value for pixels that have been marked warm
			 dim_pixel:	 32, $  // quality map value for pixels that have low sensitivity
			 saturated_ccd:  64, $	// quality map value for pixels where the CCD has saturated
			 bad_pixel:     128  $ 	// quality map value for pixels that have been marked bad
			}

END